@@ -1,4 +1,4 @@
-# $Header: /cvsroot/Apache-BruteWatch/lib/Apache/BruteWatch.pm,v 1.11 2003/08/04 23:31:08 rbowen Exp $
+# $Header: /cvsroot/Apache-BruteWatch/lib/Apache/BruteWatch.pm,v 1.13 2003/08/11 14:22:28 rbowen Exp $
 package Apache::BruteWatch;
 use strict;
 use vars qw($VERSION);
@@ -6,8 +6,7 @@ use Apache::Constants qw( :common );
 use DBI;
 use Mail::Sendmail qw();
 
-# $VERSION = qw($Revision: 1.11 $)[1];
-$VERSION = 0.11;
+$VERSION = qw($Revision: 1.13 $) [1];
 
 =head1 NAME
 
@@ -15,7 +14,7 @@ Apache::BruteWatch - Watch the Apache logs and notify of bruteforce password att
 
 =head1 VERSION
 
- $Revision: 1.11 $
+ $Revision: 1.13 $
 
 =head1 SYNOPSIS
 
@@ -75,48 +74,56 @@ sub handler {
     # We only care about unauthorized
     return OK unless $r->status == 401;
 
-    my $user = $r->dir_config('BruteDataUser');
-    my $pass = $r->dir_config('BruteDataPassword');
+    my $user  = $r->dir_config('BruteDataUser');
+    my $pass  = $r->dir_config('BruteDataPassword');
     my $dbase = $r->dir_config('BruteDatabase');
 
-    my $dbh = DBI->connect( $dbase, $user, $pass,
-        { RaiseError => 1, AutoCommit => 1, PrintError => 1}) or die
-        $DBI::errstr;
+    my $dbh =
+      DBI->connect( $dbase, $user, $pass,
+        { RaiseError => 1, AutoCommit => 1, PrintError => 1 } )
+      or die $DBI::errstr;
 
-    my $time = time;
+    my $time     = time;
     my $username = $r->user;
-    my $sth = $dbh->prepare("INSERT into bruteattempt (ts ,
-        username) values (?,?)");
-    $sth->execute($time, $username);
+    my $sth      = $dbh->prepare(
+        "INSERT into bruteattempt (ts ,
+        username) values (?,?)"
+    );
+    $sth->execute( $time, $username );
     $sth->finish;
 
     my $count = attacks( $r, $username, $time, $dbh );
 
     my $maxtries = $r->dir_config('BruteMaxTries');
-    if ($count > $maxtries) {
+    if ( $count > $maxtries ) {
         warn(
-        "Apache::BruteWatch : It appears that $username is under attack. Notification sent.");
-        notify( $r, $username, $dbh);
+"Apache::BruteWatch : It appears that $username is under attack. Notification sent."
+        );
+        notify( $r, $username, $dbh );
     }
 
     return OK;
 }
 
 sub attacks {
-    my ( $r, $username, $time, $dbh) = @_;
+    my ( $r, $username, $time, $dbh ) = @_;
     my $count;
 
     my $old = $r->dir_config('BruteMaxTime');
-    my $sth = $dbh->prepare("select count(ID) from bruteattempt where
-                username = ? and ts > $time - $old");
+    my $sth = $dbh->prepare(
+        "select count(ID) from bruteattempt where
+                username = ? and ts > $time - $old"
+    );
     $sth->execute($username);
     $sth->bind_columns( \$count );
     $sth->fetch;
     $sth->finish;
 
     my $forgive = $r->dir_config('BruteForgive');
-    $sth = $dbh->prepare("delete from bruteattempt where 
-                          ts > $time - $forgive");
+    $sth = $dbh->prepare(
+        "delete from bruteattempt where 
+                          ts > $time - $forgive"
+    );
     $sth->execute;
     $sth->finish;
 
@@ -127,18 +134,20 @@ sub notify {
     my ( $r, $username, $dbh ) = @_;
     my $count;
 
-warn "Attempting to notify";
+    warn "Attempting to notify";
 
     # Have they already been notified?
-    my $sth = $dbh->prepare("select count(ID) from brutenotified
-        where username = ?");
+    my $sth = $dbh->prepare(
+        "select count(ID) from brutenotified
+        where username = ?"
+    );
     $sth->execute($username);
     $sth->bind_columns( \$count );
     $sth->fetch;
     $sth->finish;
 
     return if $count;
-    
+
     my $notify = $r->dir_config('BruteNotify');
 
     my $message = qq~
@@ -149,17 +158,19 @@ warn "Attempting to notify";
     ~;
 
     my %mail = (
-        To => $notify,
-        From => $notify,
+        To      => $notify,
+        From    => $notify,
         Subject => "User $username under attack",
         Message => $message,
-        );
+    );
     Mail::Sendmail::sendmail(%mail);
 
-    $sth = $dbh->prepare("insert into brutenotified
+    $sth = $dbh->prepare(
+        "insert into brutenotified
         (username, ts )
         values
-        (?,?) ");
+        (?,?) "
+    );
     $sth->execute( $username, time );
     $sth->finish;
 
@@ -168,7 +179,10 @@ warn "Attempting to notify";
 
 =head1 Database
 
- CREATE TABLE bruteattempt (
+The following is a mysql database table create statement. You'll need to
+make the appropriate change to run this on some other database.
+
+  CREATE TABLE bruteattempt (
   ID int(11) NOT NULL auto_increment,
   ts int(11) default NULL,
   username varchar(255) default NULL,
@@ -190,9 +204,9 @@ warn "Attempting to notify";
  
 =head1 DATE
 
-	$Date: 2003/08/04 23:31:08 $
+	$Date: 2003/08/11 14:22:28 $
 
 =cut
 
-1; 
+1;
 
